package hideandseek.utils;

import org.bukkit.entity.Player;
import java.util.Iterator;
import java.util.ArrayList;
import org.bukkit.scoreboard.DisplaySlot;
import org.bukkit.Bukkit;
import java.util.List;
import java.util.HashMap;
import org.bukkit.scoreboard.Objective;
import org.bukkit.scoreboard.Scoreboard;

public class FlexibleScoreboard
{
    private final Scoreboard scoreboard;
    private final Objective objective;
    private final HashMap<Integer, LineEntry> lines;
    private final HashMap<String, PlaceholderEntry> placeholders;
    private final HashMap<Integer, List<String>> multiplePlaceholders;
    
    public FlexibleScoreboard(final String var1, final boolean var2, final String... var3) {
        this.scoreboard = Bukkit.getScoreboardManager().getNewScoreboard();
        this.lines = new HashMap<Integer, LineEntry>();
        this.placeholders = new HashMap<String, PlaceholderEntry>();
        this.multiplePlaceholders = new HashMap<Integer, List<String>>();
        (this.objective = this.scoreboard.registerNewObjective("HideAndSeek", "dummy")).setDisplaySlot(DisplaySlot.SIDEBAR);
        this.objective.setDisplayName(this.format(var1));
        for (int var4 = 0; var4 < var3.length; ++var4) {
            while (this.scoreboard.getEntries().contains(var3[var4])) {
                var3[var4] = var3[var4];
            }
            final String var5 = var3[var4];
            final String var6 = this.format(var3[var4]);
            final int var7 = var2 ? (-(var4 + 1)) : (var3.length - var4);
            this.objective.getScore(var6).setScore(var7);
            this.lines.put(var7, new LineEntry(var5, var6));
            final int var8 = this.getCharacterCount(var5, '%');
            if (var8 > 0 && var8 % 2 == 0) {
                if (var8 / 2 > 1) {
                    final ArrayList var9 = new ArrayList();
                    for (int var10 = 1; var10 < var8; var10 += 2) {
                        var9.add("%" + var5.split("%")[var10]);
                    }
                    this.multiplePlaceholders.put(var7, var9);
                }
                for (int var11 = 1; var11 < var8; var11 += 2) {
                    this.placeholders.put("%" + var5.split("%")[var11], new PlaceholderEntry(var7, "N/A"));
                }
            }
        }
    }
    
    public void update(final String var1, final int var2) {
        this.update(var1, String.valueOf(var2));
    }
    
    public void update(final String var1, final String var2) {
        if (this.placeholders.containsKey(var1)) {
            final PlaceholderEntry var3 = this.placeholders.get(var1);
            var3.currentValue = var2;
            final int var4 = var3.score;
            final LineEntry var5 = this.lines.get(var4);
            this.scoreboard.resetScores(var5.currentText);
            String var6 = var5.originalText;
            if (this.multiplePlaceholders.containsKey(var4)) {
                for (final String var8 : this.multiplePlaceholders.get(var4)) {
                    var6 = var6.replace(var8, this.placeholders.get(var8).currentValue);
                }
            }
            else {
                var6 = var6.replace(var1, var2);
            }
            while (this.scoreboard.getEntries().contains(var6)) {
                var6 = var6;
            }
            var6 = this.format(var6);
            this.objective.getScore(var6).setScore(var4);
            var5.currentText = var6;
        }
    }
    
    public void setNonTrackableScore(final String var1, final int var2) {
        this.objective.getScore(var1).setScore(var2);
    }
    
    private int getCharacterCount(final String var1, final char var2) {
        int var3 = 0;
        for (final char var7 : var1.toCharArray()) {
            if (var7 == var2) {
                ++var3;
            }
        }
        return var3;
    }
    
    private String format(final String var1) {
        return (var1.length() > 16) ? (Bukkit.getBukkitVersion().contains("1.7") ? var1.substring(0, 16) : ((var1.length() > 32) ? var1.substring(0, 32) : var1)) : var1;
    }
    
    public void setName(final String var1) {
        this.objective.setDisplayName(var1);
    }
    
    public void apply(final Player var1) {
        var1.setScoreboard(this.scoreboard);
    }
    
    private class LineEntry
    {
        String originalText;
        String currentText;
        
        private LineEntry(final String var2, final String var3) {
            this.originalText = var2;
            this.currentText = var3;
        }
    }
    
    private class PlaceholderEntry
    {
        int score;
        String currentValue;
        
        private PlaceholderEntry(final int var2, final String var3) {
            this.score = var2;
            this.currentValue = var3;
        }
    }
}
